
## Summary
Replace pronouns with the nouns they represent.

## Example
Run `python example.py`

## Python Version
Python 3.8.1 was used for testing

## Example
1. Pass in list of sentences ["sentence num one", "sentence num two", ...]
2. List is udpated in-place to replace pronouns with nouns they refer to.


